<dialog id="mkdocs_keyboard_modal" aria-labelledby="keyboardModalLabel">
    <div class="modal-header">
        <h4 class="modal-title" id="keyboardModalLabel">{% trans %}Keyboard Shortcuts{% endtrans %}</h4>
        <button type="button" class="modal-close" aria-label="Close"><span aria-hidden="true">&times;</span><span class="visually-hidden">{% trans %}Close{% endtrans %}</span></button>
    </div>
    <div class="modal-body">
              <table class="table">
                <thead>
                  <tr>
                    <th style="width: 20%;">{% trans %}Keys{% endtrans %}</th>
                    <th>{% trans %}Action{% endtrans %}</th>
                  </tr>
                </thead>
                <tbody>
                  <tr>
                    <td class="help shortcut"><kbd>?</kbd></td>
                    <td>{% trans %}Open this help{% endtrans %}</td>
                  </tr>
                  <tr>
                    <td class="next shortcut"><kbd>n</kbd></td>
                    <td>{% trans %}Next page{% endtrans %}</td>
                  </tr>
                  <tr>
                    <td class="prev shortcut"><kbd>p</kbd></td>
                    <td>{% trans %}Previous page{% endtrans %}</td>
                  </tr>
                  <tr>
                    <td class="search shortcut"><kbd>s</kbd></td>
                    <td>{% trans %}Search{% endtrans %}</td>
                  </tr>
                </tbody>
              </table>
            </div>
    <div class="modal-footer">
    </div>
</dialog>
