{% extends "base.html" %}

{% block htmltitle %}
<title>Graph View - {{ config.site_name }}</title>
{% endblock %}

{% block content %}
<div id="graph-container" data-graph-url="{{ 'graph.json'|url }}"></div>
{% endblock %}
