{% extends "base.html" %}

{% block content %}

    <div>
      <div id="main-content">
        <h1 id="404-page-not-found" style="text-align: center">404</h1>
        <p style="text-align: center"><strong>{% trans %}Page not found{% endtrans %}</strong></p>
      </div>
    </div>

{% endblock %}
