<dialog id="mkdocs_search_modal" class="modal-lg" aria-labelledby="searchModalLabel">
    <div class="modal-header">
        <h4 class="modal-title" id="searchModalLabel">{% trans %}Search{% endtrans %}</h4>
        <button type="button" class="modal-close" aria-label="Close"><span aria-hidden="true">&times;</span><span class="visually-hidden">{% trans %}Close{% endtrans %}</span></button>
    </div>
    <div class="modal-body">
                <p>{% trans %}From here you can search the entire zettelkasten. Enter your search terms below.{% endtrans %}</p>
                <form>
                    <div class="form-group">
                        <input type="search" class="form-control" placeholder="{% trans %}Search...{% endtrans %}" id="mkdocs-search-query" title="{% trans %}Type search term here{% endtrans %}">
                    </div>
                </form>
                <div id="mkdocs-search-results" data-no-results-text="{% trans %}No results found{% endtrans %}"></div>
            </div>
    <div class="modal-footer">
    </div>
</dialog>
