/* Selenized palette — Jan Warchol
   https://github.com/jan-warchol/selenized */

[data-color-scheme="selenized"] {
  color-scheme: light;

  /* Page backgrounds */
  --bg-page: #fbf3db;
  --bg-body-image: none;
  --bg-zettel: #fff;
  --bg-header: #ece3cc;
  --bg-accent: #ece3cc;
  --bg-code: #fbf3db;
  --bg-tooltip: #3a4d53;
  --bg-kbd: #3a4d53;
  --bg-img: #fff;

  /* Text */
  --text-primary: #53676d;
  --text-link: #0072d4;
  --text-header: #53676d;
  --text-code: #53676d;
  --text-muted: #909995;
  --text-tooltip: #ece3cc;
  --text-kbd: #fbf3db;
  --text-link-code: #0072d4;
  --text-link-code-hover: #009c8f;

  /* Borders */
  --border-zettel: #d5cdb6;
  --border-heading: #d5cdb6;
  --border-accent: #d5cdb6;
  --border-code: #d5cdb6;
  --border-hr: #d5cdb6;
  --border-img: #d5cdb6;

  /* Navbar */
  --nav-from: #53676d;
  --nav-to: #3a4d53;

  /* Admonitions */
  --adm-note-text: #0072d4;
  --adm-note-bg: #e8f0fb;
  --adm-note-border: #0072d4;
  --adm-warning-text: #ad8900;
  --adm-warning-bg: #faf0d0;
  --adm-warning-border: #ad8900;
  --adm-danger-text: #d2212d;
  --adm-danger-bg: #fce8e8;
  --adm-danger-border: #d2212d;
}

[data-color-scheme="selenized"][data-theme="dark"] {
  color-scheme: dark;

  --bg-page: #103c48;
  --bg-body-image: none;
  --bg-zettel: #184956;
  --bg-header: #1e5363;
  --bg-accent: #153f4c;
  --bg-code: #184956;
  --bg-tooltip: #cad8d9;
  --bg-kbd: #72898f;
  --bg-img: #184956;

  --text-primary: #adbcbc;
  --text-link: #4695f7;
  --text-header: #cad8d9;
  --text-code: #adbcbc;
  --text-muted: #72898f;
  --text-tooltip: #103c48;
  --text-kbd: #cad8d9;
  --text-link-code: #4695f7;
  --text-link-code-hover: #41c7b9;

  --border-zettel: #2d5b69;
  --border-heading: #2d5b69;
  --border-accent: #2d5b69;
  --border-code: #2d5b69;
  --border-hr: #2d5b69;
  --border-img: #2d5b69;

  --nav-from: #184956;
  --nav-to: #103c48;

  --adm-note-text: #4695f7;
  --adm-note-bg: #184956;
  --adm-note-border: #4695f7;
  --adm-warning-text: #dbb32d;
  --adm-warning-bg: #184956;
  --adm-warning-border: #dbb32d;
  --adm-danger-text: #fa5750;
  --adm-danger-bg: #184956;
  --adm-danger-border: #fa5750;
}
