/* Tokyo Night palette — Enkelapaj
   https://github.com/enkia/tokyo-night-vscode-theme */

[data-color-scheme="tokyo-night"] {
  color-scheme: light;

  /* Page backgrounds */
  --bg-page: #d5d6db;
  --bg-body-image: none;
  --bg-zettel: #e4e5ea;
  --bg-header: #cbccd1;
  --bg-accent: #cbccd1;
  --bg-code: #d5d6db;
  --bg-tooltip: #1a1b26;
  --bg-kbd: #1a1b26;
  --bg-img: #e4e5ea;

  /* Text */
  --text-primary: #343b58;
  --text-link: #34548a;
  --text-header: #343b58;
  --text-code: #343b58;
  --text-muted: #8990b3;
  --text-tooltip: #a9b1d6;
  --text-kbd: #d5d6db;
  --text-link-code: #34548a;
  --text-link-code-hover: #485e30;

  /* Borders */
  --border-zettel: #c0c1c8;
  --border-heading: #c0c1c8;
  --border-accent: #c0c1c8;
  --border-code: #c0c1c8;
  --border-hr: #a8a9b2;
  --border-img: #c0c1c8;

  /* Navbar */
  --nav-from: #343b58;
  --nav-to: #1a1b26;

  /* Admonitions */
  --adm-note-text: #34548a;
  --adm-note-bg: #dde2ef;
  --adm-note-border: #34548a;
  --adm-warning-text: #8f5e15;
  --adm-warning-bg: #ede5d7;
  --adm-warning-border: #8f5e15;
  --adm-danger-text: #8c4351;
  --adm-danger-bg: #ecdfe1;
  --adm-danger-border: #8c4351;
}

[data-color-scheme="tokyo-night"][data-theme="dark"] {
  color-scheme: dark;

  --bg-page: #1a1b26;
  --bg-body-image: none;
  --bg-zettel: #24283b;
  --bg-header: #2c3047;
  --bg-accent: #1f2030;
  --bg-code: #24283b;
  --bg-tooltip: #a9b1d6;
  --bg-kbd: #3b4261;
  --bg-img: #24283b;

  --text-primary: #a9b1d6;
  --text-link: #7aa2f7;
  --text-header: #c0caf5;
  --text-code: #a9b1d6;
  --text-muted: #565f89;
  --text-tooltip: #1a1b26;
  --text-kbd: #a9b1d6;
  --text-link-code: #7aa2f7;
  --text-link-code-hover: #9ece6a;

  --border-zettel: #3b4261;
  --border-heading: #3b4261;
  --border-accent: #3b4261;
  --border-code: #3b4261;
  --border-hr: #414868;
  --border-img: #3b4261;

  --nav-from: #24283b;
  --nav-to: #1a1b26;

  --adm-note-text: #7aa2f7;
  --adm-note-bg: #24283b;
  --adm-note-border: #7aa2f7;
  --adm-warning-text: #e0af68;
  --adm-warning-bg: #24283b;
  --adm-warning-border: #e0af68;
  --adm-danger-text: #f7768e;
  --adm-danger-bg: #24283b;
  --adm-danger-border: #f7768e;
}
