/* Ayu palette — ayu-theme
   https://github.com/ayu-theme/ayu-colors */

[data-color-scheme="ayu"] {
  color-scheme: light;

  /* Page backgrounds */
  --bg-page: #fcfcfc;
  --bg-body-image: none;
  --bg-zettel: #fff;
  --bg-header: #f3f4f5;
  --bg-accent: #f3f4f5;
  --bg-code: #f3f4f5;
  --bg-tooltip: #0b0e14;
  --bg-kbd: #0b0e14;
  --bg-img: #fff;

  /* Text */
  --text-primary: #5c6166;
  --text-link: #399ee6;
  --text-header: #5c6166;
  --text-code: #5c6166;
  --text-muted: #8a9199;
  --text-tooltip: #b3b1ad;
  --text-kbd: #fcfcfc;
  --text-link-code: #399ee6;
  --text-link-code-hover: #86b300;

  /* Borders */
  --border-zettel: #e1e2e4;
  --border-heading: #e1e2e4;
  --border-accent: #e1e2e4;
  --border-code: #e1e2e4;
  --border-hr: #cdd0d3;
  --border-img: #e1e2e4;

  /* Navbar */
  --nav-from: #5c6166;
  --nav-to: #464b50;

  /* Admonitions */
  --adm-note-text: #399ee6;
  --adm-note-bg: #e3f1fc;
  --adm-note-border: #399ee6;
  --adm-warning-text: #f2ae49;
  --adm-warning-bg: #fdf2e1;
  --adm-warning-border: #f2ae49;
  --adm-danger-text: #e65050;
  --adm-danger-bg: #fce4e4;
  --adm-danger-border: #e65050;
}

[data-color-scheme="ayu"][data-theme="dark"] {
  color-scheme: dark;

  --bg-page: #0b0e14;
  --bg-body-image: none;
  --bg-zettel: #0f131a;
  --bg-header: #151920;
  --bg-accent: #0d1018;
  --bg-code: #0f131a;
  --bg-tooltip: #b3b1ad;
  --bg-kbd: #2a3040;
  --bg-img: #0f131a;

  --text-primary: #b3b1ad;
  --text-link: #39bae6;
  --text-header: #d1cfca;
  --text-code: #b3b1ad;
  --text-muted: #636973;
  --text-tooltip: #0b0e14;
  --text-kbd: #b3b1ad;
  --text-link-code: #39bae6;
  --text-link-code-hover: #7fd962;

  --border-zettel: #1c2028;
  --border-heading: #1c2028;
  --border-accent: #1c2028;
  --border-code: #1c2028;
  --border-hr: #2a3040;
  --border-img: #1c2028;

  --nav-from: #0f131a;
  --nav-to: #0b0e14;

  --adm-note-text: #39bae6;
  --adm-note-bg: #0f131a;
  --adm-note-border: #39bae6;
  --adm-warning-text: #e6b450;
  --adm-warning-bg: #0f131a;
  --adm-warning-border: #e6b450;
  --adm-danger-text: #d95757;
  --adm-danger-bg: #0f131a;
  --adm-danger-border: #d95757;
}
